# django-dpa-chile

<!-- [![Build Status][travis-image]][travis-url]
[![Coverage percentage][coveralls-image]][coveralls-url]
[![PyPI status][pypi-image]][pypi-url] -->

> Political-Administrative Division of Chile

## Installation

install `django-dpa-chile` using `pip`

```sh
pip install -U django-dpa-chile
```

add `django_dpa_chile` to INSTALLED_APPS

__settings.py__

```python
# ...

INSTALLED_APPS =[
  ...
  'django_dpa_chile'
  ]

# ...
```

## [License](LICENSE)

Francisco Jordan &lt;franciscojordan@live.com&gt;

<!-- [travis-image]: https://travis-ci.org/jupitercl/django-dpa-chile.svg?branch=master
[travis-url]: https://travis-ci.org/jupitercl/django-dpa-chile
[coveralls-image]: https://coveralls.io/repos/jupitercl/django-dpa-chile/badge.svg
[coveralls-url]: https://coveralls.io/r/jupitercl/django-dpa-chile
[pypi-image]: https://img.shields.io/pypi/v/django-dpa-chile.svg -->
[pypi-url]: https://pypi.python.org/pypi/django-dpa-chile/
